@@ -172,15 +172,17 @@ double cpp_ll_genetic(Rcpp::List data, Rcpp::List param, SEXP i,
 
 
 double cpp_ll_genetic(Rcpp::List data, Rcpp::List param, size_t i,
-		      Rcpp::RObject custom_function) {
-  return cpp_ll_genetic(data, param, Rcpp::wrap(i), custom_function);
+              Rcpp::RObject custom_function) {
+  SEXP si = PROTECT(Rcpp::wrap(i));
+  double ret = cpp_ll_genetic(data, param, si, custom_function);
+  UNPROTECT(1);
+  return ret;
 }
 
 
 
 
 
-
 // ---------------------------
 
 // This likelihood corresponds to the probability of observing infection dates
@@ -247,15 +249,17 @@ double cpp_ll_timing_infections(Rcpp::List data, Rcpp::List param, SEXP i,
 
 
 double cpp_ll_timing_infections(Rcpp::List data, Rcpp::List param, size_t i,
-				Rcpp::RObject custom_function) {
-  return cpp_ll_timing_infections(data, param, Rcpp::wrap(i), custom_function);
+              Rcpp::RObject custom_function) {
+  SEXP si = PROTECT(Rcpp::wrap(i));
+  double ret = cpp_ll_timing_infections(data, param, si, custom_function);
+  UNPROTECT(1);
+  return ret;
 }
 
 
 
 
 
-
 // ---------------------------
 
 // This likelihood corresponds to the probability of reporting dates of cases
@@ -307,15 +311,17 @@ double cpp_ll_timing_sampling(Rcpp::List data, Rcpp::List param, SEXP i,
 
 
 double cpp_ll_timing_sampling(Rcpp::List data, Rcpp::List param, size_t i,
-			      Rcpp::RObject custom_function) {
-  return cpp_ll_timing_sampling(data, param, Rcpp::wrap(i), custom_function);
+              Rcpp::RObject custom_function) {
+  SEXP si = PROTECT(Rcpp::wrap(i));
+  double ret = cpp_ll_timing_sampling(data, param, si, custom_function);
+  UNPROTECT(1);
+  return ret;
 }
 
 
 
 
 
-
 // ---------------------------
 
 // This likelihood corresponds to the probability of a given number of
@@ -382,15 +388,17 @@ double cpp_ll_reporting(Rcpp::List data, Rcpp::List param, SEXP i,
 
 
 double cpp_ll_reporting(Rcpp::List data, Rcpp::List param, size_t i,
-			Rcpp::RObject custom_function) {
-  return cpp_ll_reporting(data, param, Rcpp::wrap(i), custom_function);
+              Rcpp::RObject custom_function) {
+  SEXP si = PROTECT(Rcpp::wrap(i));
+  double ret = cpp_ll_reporting(data, param, si, custom_function);
+  UNPROTECT(1);
+  return ret;
 }
 
 
 
 
 
-
 // ---------------------------
 
 // This likelihood corresponds to the probability of observing a a reported
@@ -470,15 +478,17 @@ double cpp_ll_contact(Rcpp::List data, Rcpp::List param, SEXP i,
 
 
 double cpp_ll_contact(Rcpp::List data, Rcpp::List param, size_t i,
-		      Rcpp::RObject custom_function) {
-  return cpp_ll_contact(data, param, Rcpp::wrap(i), custom_function);
+              Rcpp::RObject custom_function) {
+  SEXP si = PROTECT(Rcpp::wrap(i));
+  double ret = cpp_ll_contact(data, param, si, custom_function);
+  UNPROTECT(1);
+  return ret;
 }
 
 
 
 
 
-
 // ---------------------------
 
 // This likelihood corresponds to the sums of the separate timing likelihoods,
@@ -501,11 +511,14 @@ double cpp_ll_timing(Rcpp::List data, Rcpp::List param, SEXP i,
   }
 }
 
-double cpp_ll_timing(Rcpp::List data, Rcpp::List param, size_t i,
-		     Rcpp::RObject custom_functions) {
-  return cpp_ll_timing(data, param, Rcpp::wrap(i), custom_functions);
-}
 
+double cpp_ll_timing(Rcpp::List data, Rcpp::List param, size_t i,
+              Rcpp::RObject custom_function) {
+  SEXP si = PROTECT(Rcpp::wrap(i));
+  double ret = cpp_ll_timing(data, param, si, custom_function);
+  UNPROTECT(1);
+  return ret;
+}
 
 
 
@@ -546,6 +559,9 @@ double cpp_ll_all(Rcpp::List data, Rcpp::List param, SEXP i,
 
 
 double cpp_ll_all(Rcpp::List data, Rcpp::List param, size_t i,
-		  Rcpp::RObject custom_functions) {
-  return cpp_ll_all(data, param, Rcpp::wrap(i), custom_functions);
+              Rcpp::RObject custom_function) {
+  SEXP si = PROTECT(Rcpp::wrap(i));
+  double ret = cpp_ll_all(data, param, si, custom_function);
+  UNPROTECT(1);
+  return ret;
 }
